@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11627 2019-06-10 19:47:08Z Lavender $
+# $Id: __init__.py 11639 2019-06-19 05:13:41Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-06-11 04:47:08 +0900 (週二, 11 六月 2019) $
-# $Revision: 11627 $
+# $Date: 2019-06-19 14:13:41 +0900 (週三, 19 六月 2019) $
+# $Revision: 11639 $
 
 import os
 import sys
@@ -54,8 +54,6 @@ from Iuppiter.Logging import createLogger
 
 logger = createLogger(__name__)
 
-ENCRYPTION_KEY = "25025529"
-
 CKEDITOR_CONFIGS = {
     'default': {
         'skin': 'moono',
@@ -982,22 +980,17 @@ def buildAPIForm(submission, request, apiName, extra={}):
         
     if not form:
         return None
-    else:      
-        """
+    else:             
         if six.PY3:
             if not isinstance(form, bytes):
                 form = str(form).encode()
-            encryptor = Encryptor(ENCRYPTION_KEY.encode())
+            encryptor = Encryptor(settings.SECRET_KEY.encode())
             formData = encryptor.encrypt(form)
         else:
-            encryptor = Encryptor(ENCRYPTION_KEY)
+            encryptor = Encryptor(settings.SECRET_KEY)
             formData = encryptor.encrypt(form)
-        """
         
-        if not isinstance(form, bytes):
-            form = str(form).encode()
-            
-        form = base64.b64encode(form)
+        form = base64.b64encode(formData)
             
         temp = get_template('shop/payment/PaymentForm.html')
         if DJANGO_VERSION >= 11100: # django >= 1.11
